#
# spec file for package python-django-model-utils
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-django-model-utils
Version:        4.4.0
Release:        1.5
Summary:        Django model mixins and utilities
License:        BSD-3-Clause
URL:            https://github.com/jazzband/django-model-utils
Source:         https://files.pythonhosted.org/packages/source/d/django-model-utils/django-model-utils-%{version}.tar.gz
# Upstreamed to https://github.com/jazzband/django-model-utils/pull/516
Patch0:         use-sqlite.patch
BuildRequires:  %{python_module Django >= 2.0}
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module freezegun}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest-django}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
Requires:       python-Django >= 2.0
BuildArch:      noarch
%python_subpackages

%description
Django model mixins and utilities.

%prep
%autosetup -p1 -n django-model-utils-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# skip JoinManagerTest tests as they need proper DB (pgsql/mysql)
export PYTHONPATH=.
export SQLITE=1
%pytest -k 'not JoinManagerTest'

%files %{python_files}
%license LICENSE.txt
%doc AUTHORS.rst CHANGES.rst README.rst
%{python_sitelib}/model_utils
%{python_sitelib}/django_model_utils-%{version}.dist-info

%changelog
* Thu Feb 22 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 4.4.0:
  * Add support for `Python 3.11`
  * Add support for `Python 3.12`
  * Drop support for `Python 3.7`
  * Add support for `Django 4.2`
  * Add support for `Django 5.0`
  * Remove ``SaveSignalHandlingModel``. This model used a modified copy of
    the internal Django method `Model.save_base()` and had not been updated
    for upstream bug fixes changes since its addition.
  * Add Swedish translation
  * Use proper column name instead of attname
  * Fix ValueError when calling prefetch_related for tracked ForeignKey fields
- Switch to autosetup and pyproject macros.
- No more greedy globs in %%files.
* Wed Jan  4 2023 Dirk Müller <dmueller@suse.com>
- update to 4.3.1:
  * Confirm support for `Django 4.0`
  * Add Spanish translation
  * Add French translation
  * Drop Django 1.7 workaround from `select_subclasses()`
  * Drop support for `Django < 3.2`
  * Drop support for `Python 3.6`
  * Confirm support for `Django 4.1`
* Fri Jan  7 2022 John Vandenberg <jayvdb@gmail.com>
- Skip Tumbleweed Python 3.6 incompatible with Django 4
* Sun Dec 26 2021 John Vandenberg <jayvdb@gmail.com>
- Update to v4.2.0
  * Add support for Django 3.2
  * Drop support for Django 3.0
  * Add support for Python 3.10
  * Added urlsafe token field.
  * Introduce context manager for FieldTracker state reset
  * Fix performance regression of FieldTracker on FileField subclasses
    on Django 3.1+
- from v4.1.1
  * Applied isort to codebase
  * Fix TypeError in save when model inherits from both
    TimeStampModel and StatusModel.
- from v4.1.0
  * FieldTracker now marks fields as not changed after
    refresh_from_db respecting fields argument
  * FieldTracker now respects update_fields changed in overridden
    save() method
  * FieldTracker now resets states after pre_save() and not anymore
    save() signals, possibly altering the behaviour of overridden
    save() methods
  * Update InheritanceQuerySetMixin to avoid querying too much tables
  * TimeStampedModel now automatically adds 'modified' field as an
    update_fields parameter even if it is forgotten while using save()
  * Replace ugettext_lazy with gettext_lazy
  * Add available_objects manager to SoftDeletableModel and add
    deprecation warning to objects manager.
  * StatusModel now automatically adds 'status_changed' field during
    save as an update_fieldsparameter when 'status' is present in it
    to make sure it is not forgotten.
  * Drop support for Django 2.1
  * Add support for Python 3.9
  * Add support for Django 3.1
* Wed Sep  2 2020 Marketa Calabkova <mcalabkova@suse.com>
- Fix test execution
* Tue Jan  7 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 4.0.0:
  * Added Choices.subset.
  * Remove hacks for previously supported Django versions. (Fixes GH-390)
  * Dropped support for Python 2.7. (Fixes GH-393)
  * Dropped usage of six
  * Drop support for Django 1.11
  * Add support for Python 3.8
  * Add support for Django 3.0
* Tue Jul  2 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patch use-sqlite.patch to use sqlite for testing and not
  postgresql
* Tue Jul  2 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.2.0:
  * Catch AttributeError for deferred abstract fields, fixes GH-331.
  * Update documentation to explain usage of timeframed model manager, fixes GH-118
  * Honor OneToOneField.parent_link=False.
  * Fix handling of deferred attributes on Django 1.10+, fixes GH-278
  * Fix FieldTracker.has_changed() and FieldTracker.previous() to return correct responses for deferred fields.
  * Add Simplified Chinese translations.
  * Update AutoLastModifiedField so that at instance creation it will always be set equal to created to make querying easier. Fixes GH-254
  * Support reversed for all kinds of Choices objects, fixes GH-309
  * Fix Model instance non picklable GH-330
  * Fix patched save in FieldTracker
  * Upgrades test requirements (pytest, pytest-django, pytest-cov) and skips tox test with Python 3.5 and Django (trunk)
  * Add UUIDModel and UUIDField support.
- Remove upstream merged fix-deferred.patch
* Wed Apr 24 2019 Tomáš Chvátal <tchvatal@suse.com>
- Fix requires on python-Django
* Wed Feb 20 2019 John Vandenberg <jayvdb@gmail.com>
- Update to version 3.1.2
- Patch for Django 2
* Sat Feb 16 2019 John Vandenberg <jayvdb@gmail.com>
- Update to support Python 3
* Fri Jan 31 2014 p.drouand@gmail.com
- Update to version 2.0
  + BACKWARDS-INCOMPATIBLE: Indexing into a ``Choices`` instance now
    translates database representations to human-readable choice names,
    rather than simply indexing into an array of choice tuples. (Indexing
    into ``Choices`` was previously not documented.) If you have code
    that is relying on indexing or slicing ``Choices``, the simplest
    workaround is to change e.g. ``STATUS[1:]`` to ``list(STATUS)[1:]``.
  + Fixed bug with checking for field name conflicts for added query
    managers on `StatusModel`.
  + Can pass `choices_name` to `StatusField` to use a different name
    for choices class attribute. ``STATUS`` is used by default.
  + Can pass model subclasses, rather than strings, into `select_subclasses()`
  + Deepcopying a `Choices` instance no longer fails with infinite
    recursion in `getattr`.
  + `get_subclass()` method is now available on both managers and querysets
  + Fix bug in `InheritanceManager` with grandchild classes on Django 1.6+;
    `select_subclasses('child', 'child__grandchild')` would only ever get
    to the child class.
  + MonitorField now accepts a 'when' parameter. It will update only
    when the field changes to one of the values specified.
* Sat Sep 28 2013 p.drouand@gmail.com
- Update to version 1.5.0
  + Choices now accepts option-groupings. Fixes GH-14.
  + Choices can now be added to other Choices or to any iterable, and can
    be compared for equality with itself.
  + Choices now __contains__ its Python identifier values.
  + Fixed a bug causing KeyError when saving with the parameter update
  _fields in which there are untracked fields.
  +  Fixed FieldTracker usage on inherited models. Fixes GH-57.
  +  Added mutable field support to FieldTracker
- Use download url as source url
- Replace python-distribute with python-setuptools BuildRequires
- Add documentation from tarball
* Mon Jan 28 2013 alexandre@exatati.com.br
- Update to 1.2.0:
  - Moved primary development from Bitbucket to GitHub. Bitbucket
    mirror will continue to receive updates; Bitbucket issue tracker
    will be closed once all issues tracked in it are resolved.
  - Removed deprecated ChoiceEnum, InheritanceCastModel,
    InheritanceCastManager, and manager_from.
  - Fixed pickling of PassThroughManager. Thanks Rinat Shigapov.
  - Set use_for_related_fields = True on QueryManager.
  - Added __len__ method to Choices. Thanks Ryan Kaskel and James
    Oakley.
  - Fixed InheritanceQuerySet on Django 1.5. Thanks Javier García
    Sogo.
* Sat Apr 14 2012 alexandre@exatati.com.br
- Update to 1.1.0:
  - Updated AutoCreatedField, AutoLastModifiedField, MonitorField, and
    TimeFramedModel to use ``django.utils.timezone.now`` on Django 1.4.
    Thanks Donald Stufft.
  - Fixed annotation of InheritanceQuerysets. Thanks Jeff Elmore and Facundo
    Gaich.
  - Dropped support for Python 2.5 and Django 1.1. Both are no longer supported
    even for security fixes, and should not be used.
  - Added ``PassThroughManager.for_queryset_class()``, which fixes use of
    ``PassThroughManager`` with related fields. Thanks Ryan Kaskel for report and
    fix.
- Added ``InheritanceManager.get_subclass()``. Thanks smacker.
* Fri Jun 17 2011 alexandre@exatati.com.br
- Update to 1.0.0:
  - Fixed using SplitField on an abstract base model.
  - Fixed issue #8, adding ``use_for_related_fields = True`` to
    ``InheritanceManager``.
  - Added ``PassThroughManager``. Thanks Paul McLanahan.
  - Added pending-deprecation warnings for ``InheritanceCastModel``,
    ``manager_from``, and Django 1.1 support. Removed documentation for the
    deprecated utilities. Bumped ``ChoiceEnum`` from pending-deprecation to
    deprecation.
  - Fixed issue #6, bug with InheritanceManager and descriptor fields (e.g.
    FileField).  Thanks zyegfryed for the fix and sayane for tests.
- Regenerate spec file with py2pack.
* Fri Feb 18 2011 alexandre@exatati.com.br
- Update to 0.6.0:
  - Updated SplitField to define get_prep_value rather than
    get_db_prep_value. This avoids deprecation warnings on Django
    trunk/1.3, but makes SplitField incompatible with Django
    versions prior to 1.2.
  - Added InheritanceManager, a better approach to selecting
    subclass instances for Django 1.2+. Thanks Jeff Elmore.
  - Added InheritanceCastManager and InheritanceCastQuerySet, to
    allow bulk casting of a queryset to child types. Thanks Gregor
    Müllegger.
* Fri Sep 24 2010 alexandre@exatati.com.br
- Update to 0.5.0;
- Bzip2 source file;
- Spec file cleaned with spec-cleaner.
* Wed Mar 17 2010 alexandre@exatati.com.br
- Update to 0.4.0.
* Tue Oct 27 2009 alexandre@exatati.com.br
- Initial package (0.3.1) for openSUSE.
